package com.community.huiju.common.hk;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.community.commom.hk.Digests;
import com.community.commom.hk.HttpClientSSLUtils;
import com.community.huiju.common.PicUtils;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 海康 API
 * @author weiximei
 */
@Slf4j
public class HKOpenApi {

    /**
     * 根据
     * 组织中心UUID集 ,第几页, 一页多少行
     *
     * 获取  监控点 数据列表
     * @return
     */
    public static String getMonitoryPoint(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_MONITORY_POINT;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",map.get("pageNo"));
        parMap.put("pageSize",map.get("pageSize"));
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("unitUuids",map.get("unitUuids"));
        String params =  JSON.toJSONString(parMap);
        log.info("获取 监控列表 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("获取 监控列表 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取监控列表失败!",e);
            throw new RuntimeException("获取监控列表失败!");
        }

        return data;
    }

    /**
     * 根据部门名称分页获取部门
     *      第几页, 一页多少行, 操作用户uuid
     * @param map
     * @return
     */
    public static String getDeptName(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_LIKE_DEPT_NAME;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",map.get("pageNo"));
        parMap.put("pageSize",map.get("pageSize"));
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("deptName",map.get("deptName"));
        String params =  JSON.toJSONString(parMap);
        log.info("根据部门名称分页获取部门 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("根据部门名称分页获取部门 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据部门名称分页获取部门失败!",e);
            throw new RuntimeException("根据部门名称分页获取部门失败!");
        }

        return data;
    }


    /**
     * 添加人员
     *
     *      比如 住户
     * @return
     */
    public static String addUser(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_ADD_USER;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("personNo",map.get("personNo"));
        parMap.put("personName",map.get("personName"));
        parMap.put("phoneNo",map.get("phoneNo"));
        parMap.put("deptUuid",map.get("deptUuid"));
        // parMap.put("cardNo",map.get("cardNo"));
        String params =  JSON.toJSONString(parMap);
        log.info("添加人员 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("添加人员 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("添加人员失败!",e);
            throw new RuntimeException("添加人员失败!");
        }

        return data;
    }

    /**
     * 批量开卡
     *
     * 其中参数 cardAndPerson 形式为“卡号，人员ID”，开卡数量不得超过50个，若没有该卡号，则添加一张新卡进行绑定 List<String>
     * @return
     */
    public static String openCard(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_OPEN_CARD;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("cardAndPerson",map.get("cardAndPerson"));
        parMap.put("startTime",map.get("startTime"));
        parMap.put("endTime",map.get("endTime"));
        parMap.put("subSystems","1048576,3145728,2097152,9437184,25165824,10485760");
        String params =  JSON.toJSONString(parMap);
        log.info("批量开卡 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("批量开卡 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("批量开卡失败!",e);
            throw new RuntimeException("批量开卡失败!");
        }

        return data;
    }

    /**
     * 根据中心UUID集获取中心下的门禁设备信息
     *
     * @return
     */
    public static String getACDevicesByUnitUuids(){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_MONITORY_POINT;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",1);
        parMap.put("pageSize",10);
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("unitUuids","1048576");
        String params =  JSON.toJSONString(parMap);
        log.info("获取中心UUID集获取中心下的门禁设备请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("获取 中心UUID集获取中心下的门禁设备 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取失败!",e);
            throw new RuntimeException("获取失败!");
        }

        return data;
    }

    /**
     * 分页获取门禁点信息。
     *
     * @return
     */
    public static String getDoors(){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_MONITORY_POINT;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",1);
        parMap.put("pageSize",10);
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        String params =  JSON.toJSONString(parMap);
        log.info("分页获取门禁点信息请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("分页获取门禁点信息 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取失败!",e);
            throw new RuntimeException("获取失败!");
        }

        return data;
    }

    /**
     * 批量获取控制中心信息，多个中心的UUID用“,”分割组成的字符串。
     *
     * @return
     */
    public static String getUnitsByUuids(){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_MONITORY_POINT;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",1);
        parMap.put("pageSize",10);
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("unitUuids","1048576");
        String params =  JSON.toJSONString(parMap);
        log.info("获取控制中心信息请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("获取控制中心信息 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取控制中心信息失败!",e);
            throw new RuntimeException("获取控制中心信息失败!");
        }

        return data;
    }

    /**
     *  根据中心UUID分页获取下级区域
     * @return
     */
    public static String getRegionsByUnitUuid(){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_MONITORY_POINT;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",1);
        parMap.put("pageSize",10);
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("parentUuid","1048576");
        parMap.put("allChildren",1);
        String params =  JSON.toJSONString(parMap);
        log.info("根据中心UUID分页获取下级区域请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("根据中心UUID分页获取下级区域 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据中心UUID分页获取下级区域获取失败!",e);
            throw new RuntimeException("根据中心UUID分页获取下级区域获取失败!");
        }

        return data;
    }

    /**
     * 根据区域UUID集获取门禁点
     * @return
     */
    public static String getDoorsByRegionUuids(){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.DOORS_BY_REGION_UUIDS;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("regionUuids","2a36878c9a4a49d290d253ac1b4746dc");
        String params =  JSON.toJSONString(parMap);
        log.info("根据区域UUID集获取门禁点请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("根据区域UUID集获取门禁点 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据区域UUID集获取门禁点获取失败!",e);
            throw new RuntimeException("根据区域UUID集获取门禁点获取失败!");
        }

        return data;
    }

    /**
     * 根据人员ID集添加权限
     * @return
     */
    public static String addAuthoritiesByPersonIds(String personIds){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ADD_AUTHORITIES_BY_PERSONIDS;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("personIds",personIds);
        parMap.put("doorGroupUuids","");
        parMap.put("doorUuids","efcb9a3fe4e64e2f9c0f546c54465524,94bac7e217fb4a698ad086876d347c6a,369b49476a364f87b1c50e99435ecca8,22d8a043cd3f41c5bf1bd976ab5ee65d");
        String params =  JSON.toJSONString(parMap);
        log.info("根据人员ID集添加权限请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("根据人员ID集添加权限 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据人员ID集添加权限!",e);
            throw new RuntimeException("根据人员ID集添加权限!");
        }

        return data;
    }

    /**
     * 根据设备UUID集异动下载门禁权限
     * @return
     */
    public static String downloadAuthorityByDeviceUuids(){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.DOWNLOAD_AUTHORITY_BY_DEVICEUUIDS;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("deviceUuids","dfd80b22f00545b8b36fa981019df83c,d60ba7a952a94da5ba6daaa2cd62ec20,c8cbac0b4a514ad0921a3f12a542f2d3,c8cbac0b4a514ad0921a3f12a542f2d3");
        String params =  JSON.toJSONString(parMap);
        log.info("根据设备UUID集异动下载门禁权限请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("根据设备UUID集异动下载门禁权限 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据设备UUID集异动下载门禁权限获取失败!",e);
            throw new RuntimeException("根据设备UUID集异动下载门禁权限获取失败!");
        }

        return data;
    }

    /**
     * 指定人员的门禁权限下载
     *
     * @param personIds 人员ID, 多个用 "," 隔开
     * @return
     */
    public static String downloadAuthorityByPersonIds(String personIds){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.DOWNLOAD_AUTHORITY_BY_PERSONIDS;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("personIds",personIds);
        parMap.put("doorUuids","efcb9a3fe4e64e2f9c0f546c54465524,94bac7e217fb4a698ad086876d347c6a,369b49476a364f87b1c50e99435ecca8,22d8a043cd3f41c5bf1bd976ab5ee65d");
        parMap.put("planUuid","plan0000000000000000000000000001");
        parMap.put("operateType",1);
        parMap.put("includeFinger",1);
        String params =  JSON.toJSONString(parMap);
        log.info("指定人员的门禁权限下载请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("获取 指定人员的门禁权限下载 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("指定人员的门禁权限下载获取失败!",e);
            throw new RuntimeException("指定人员的门禁权限下载获取失败!");
        }

        return data;
    }

    /**
     * 分页获取计划模板
     *
     * @param pageNo 第几页
     * @param pageSize 一页多少行
     * @return
     */
    public static String getPlans(Integer pageNo, Integer pageSize) {

        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.GETPLANS;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("pageNo",pageNo);
        parMap.put("pageSize",pageSize);
        String params =  JSON.toJSONString(parMap);
        log.info("分页获取计划模板请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("获取 分页获取计划模板 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("分页获取计划模板获取失败!",e);
            throw new RuntimeException("分页获取计划模板获取失败!");
        }

        return data;
    }

    /**
     * 指定人员人脸/指纹权限下载
     * @return
     */
    public static String downloadFaceAndFingerInfos(String personIds){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.DOWNLOAD_FACE_AND_FINGERINFOS;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("deviceUuids","d60ba7a952a94da5ba6daaa2cd62ec20,dfd80b22f00545b8b36fa981019df83c");
        parMap.put("personIds",personIds);
        parMap.put("type",1);
        String params =  JSON.toJSONString(parMap);
        log.info("指定人员人脸/指纹权限下载 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("指定人员人脸/指纹权限下载 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("指定人员人脸/指纹权限下载获取失败!",e);
            throw new RuntimeException("指定人员人脸/指纹权限下载获取失败!");
        }

        return data;
    }
    /**
     * 添加人脸
     * faceImg 图片
     * personNo 人员编号
     * personName 名称
     * @return
     */
    public static String HKpersonGroupId(MultipartFile faceImg,Integer personNo,String personName){
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_ADD_USER;
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("appkey", HKConstant.APPKEY);
        map.put("time", System.currentTimeMillis());
        map.put("token", HKConstant.SECRET);
        map.put("opUserUuid",HKConstant.OP_USER_UUID);
        map.put("personNo",personNo);
        map.put("personName",personName);
        String params =  JSON.toJSONString(map);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("添加人脸失败!");
        }
        return data;
    }


    /**
     * 修改人脸
     * faceImg 图片
     * personId人员ID
     * personNo 人员编号
     * personName 名称
     *  * personName 卡号
     * @return
     */
    public static String HKpersonGroupId(MultipartFile faceImg,Integer personId,Integer personNo,String personName,String cardNo) {
        byte [] fileByte = new byte[0];
        try {
            fileByte = faceImg.getBytes();
        } catch (IOException e) {
            e.printStackTrace();
        }
        byte[] imgs=PicUtils.compressPicForScale(fileByte,99L,"x");

        String img = PicUtils.getImgStr(imgs);
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_UPDATE_USER;
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("appkey", HKConstant.APPKEY);
        map.put("time", System.currentTimeMillis());
        map.put("token", HKConstant.SECRET);
        map.put("opUserUuid", HKConstant.OP_USER_UUID);
        map.put("personId", personId);
        map.put("personNo", personNo);
        map.put("personName", personName);
        map.put("facePhoto", img);
        map.put("cardNo", cardNo);
        String params = JSON.toJSONString(map);
        log.info("修改人脸 请求参数：{}",params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("修改人脸请求结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("修改人脸 请求失败：{}",e);
            throw new RuntimeException("修改人脸失败!");
        }

        return data;
    }

    /**
     * 修改人员
     *
     *  比如 住户
     *
     * @return
     */
    public static String updateUser(Map<String,Object> map) {
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_UPDATE_USER;
        Map<String, Object> parMap = new HashMap<String, Object>();
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("personNo",map.get("personNo"));
        parMap.put("personId",map.get("personId"));
        parMap.put("personName",map.get("personName"));
        parMap.put("phoneNo",map.get("phoneNo"));
        parMap.put("deptUuid",map.get("deptUuid"));
        String params =  JSON.toJSONString(parMap);
        log.info("修改人员 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("修改人员 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("修改加人员失败!",e);
            throw new RuntimeException("修改加人员失败!");
        }
        return data;
    }


    /**
     * 未预约登记
     * @param visitorName 访客姓名
     * @param phoneNo 联系电话
     * @param personNum 来访人数
     * @param startTime 来访时间
     * @param endTime 离开时间
     * @param personId 被访人ID
     * @return
     */
    public static String temporaryRegister(String visitorName, String phoneNo,Integer personNum,Long startTime,Long endTime,Integer personId){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.TEMPORARY_REGISTER;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        
        parMap.put("visitorName",visitorName);
        parMap.put("gender",1);
        parMap.put("identityType",0);
        parMap.put("phoneNo",phoneNo);
        parMap.put("personNum",personNum);
        parMap.put("startTime",startTime);
        parMap.put("endTime",endTime);
        parMap.put("isVip",0);
        parMap.put("personId",personId);
        String params =  JSON.toJSONString(parMap);
        log.info("未预约登记 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("未预约登记 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取失败!",e);
            throw new RuntimeException("获取失败!");
        }
    
        return data;
    }
    
    public static void main(String[] args) {
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + "/openapi/service/eps/subscribeEventsFromMQEx";
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("eventTypes","198914,199941,983309,983299");
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        String params =  JSON.toJSONString(parMap);
        log.info("分页获取门禁点信息请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("分页获取门禁点信息 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取失败!",e);
            throw new RuntimeException("获取失败!");
        }
    
        System.out.println(data);
    }


    /**
     * 修改电话推送海康
     * @param personId 人员ID
     * @param personNo 人员编号
     * @param personName 姓名
     * @param phoneNo 电话
     * @return
     */
    public static String HKpersonPhone(Integer personId,Integer personNo,String personName,String phoneNo) {

        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_UPDATE_USER;
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("appkey", HKConstant.APPKEY);
        map.put("time", System.currentTimeMillis());
        map.put("token", HKConstant.SECRET);
        map.put("opUserUuid", HKConstant.OP_USER_UUID);
        map.put("personId", personId);
        map.put("personNo", personNo);
        map.put("personName", personName);
        map.put("phoneNo", phoneNo);
        String params = JSON.toJSONString(map);
        log.info("修改电话 请求参数：{}",params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("修改电话请求结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("修改电话 请求失败：{}",e);
            throw new RuntimeException("修改电话失败!");
        }
        return data;
    }
}
