package com.community.huiju.dao;

import com.community.huiju.model.TaUser;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

@Mapper
public interface TaUserMapper {
    int deleteByPrimaryKey(Integer id);

    int insert(TaUser record);

    int insertSelective(TaUser record);

    TaUser selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(TaUser record);

    int updateByPrimaryKey(TaUser record);

    /**
     * 根据loginName和loginPassword 查询用户
     * @param map
     * @return 用户
     */
    TaUser selectByLoginNameAndByLoginPassword(Map<String, Object> map);

    /**
     * 根据loginName 查询用户
     * @param map
     * @return 用户
     */
    TaUser selectByLoginName(Map<String, Object> map);

    /**
     * 更新当前用户电话
     * @param record
     * @return
     */
    TaUser updateLongName(TaUser record);

    /**
     * 查询房屋成员列表
     * @param parentId
     * @return
     */
    List<TaUser> selectUserListByParentId(Integer parentId);

    /**
     * 判断当前用户的关联关系
     * @param userId
     * @param otherUserId
     * @return
     */
    TaUser selectTaFaceParentId(@Param("id") Integer userId, @Param("otherUserId") Integer otherUserId);

    /**
     * 查询此电话在小区是否存在
     * @param communityId
     * @param phone
     * @return
     */
    TaUser getByLoginName(@Param("id") Integer communityId, @Param("id") String phone);

    /**
     * 查询 业主/家属/租客 的总数
     *
     *  1 业主  2 租客  3 家属
     * @param roleId 角色ID(业主/家属/租客)
     * @return
     */
    Integer getByUserTypeCount(Integer roleId);

    /**
     * 获取 家属 总数(包含业主)
     *
     *  1 业主  2 租客  3 家属
     *
     * @return
     */
    Integer getOwnerCount();
}